Learn R Programming

spatstat.geom (version 3.7-3)

affine.owin: Apply Affine Transformation To Window

Description

Applies any affine transformation of the plane (linear transformation plus vector shift) to a window.

Usage

# S3 method for owin
affine(X, mat=diag(c(1,1)), vec=c(0,0), ..., rescue=TRUE)

Arguments

Value

Another window (of class "owin") representing the result of applying the affine transformation.

Details

The window is subjected first to the linear transformation represented by mat (multiplying on the left by mat), and then the result is translated by the vector vec.

The argument mat must be a nonsingular \(2 \times 2\) matrix.

This is a method for the generic function affine.

See Also

affine, affine.ppp, affine.psp, affine.im, rotate, shift

Examples

Run this code
  # shear transformation
  shear <- matrix(c(1,0,0.6,1),ncol=2)
  X <- affine(owin(), shear)
  if(interactive()) plot(X)
  affine(letterR, shear, c(0, 0.5))
  affine(as.mask(letterR), shear, c(0, 0.5))

Run the code above in your browser using DataLab