Learn R Programming

spatstat.geom (version 3.7-2)

as.colourmap: Convert to Colour Map

Description

Convert some other kind of data to a colour map.

Usage

as.colourmap(x, ...)

# S3 method for colourmap as.colourmap(x, ...)

# S3 method for symbolmap as.colourmap(x, ..., warn=TRUE)

Arguments

Value

A colour map (object of class "colourmap") or NULL.

Details

If x contains colour map information, it will be extracted and returned as a colour map object. Otherwise, NULL will be returned (and a warning will be issued if warn=TRUE, the default).

See Also

colourmap

Examples

Run this code
  m <- pHcolourmap(c(3,8))
  g <- symbolmap(pch=21, bg=m, size=function(x){ 1.1 * x }, range=c(3,8))
  opa <- par(mfrow=c(1,2))
  plot(g, vertical=TRUE)
  plot(as.colourmap(g), vertical=TRUE)
  par(opa)

Run the code above in your browser using DataLab