powered by
Given a list of two-dimensional spatial objects, convert it to the class "solist".
"solist"
as.solist(x, ...)
A list, usually of class "solist".
This command makes the list x into an object of class "solist" (spatial object list). See solist for details.
x
solist
The entries in the list x should be two-dimensional spatial datasets (not necessarily of the same class).
solist, as.anylist, solapply.
as.anylist
solapply
x <- list(cells, Window(cells), setcov(Window(cells))) y <- as.solist(x)
Run the code above in your browser using DataLab