Learn R Programming

spatstat.geom (version 3.7-2)

contour.imlist: Array of Contour Plots

Description

Generates an array of contour plots.

Usage

# S3 method for imlist
contour(x, ...)

# S3 method for listof contour(x, ...)

Arguments

Value

Null.

Details

This is a method for the generic command contour for the class "imlist". An object of class "imlist" represents a list of pixel images.

(The outdated class "listof" is also handled.)

Each entry in the list x will be displayed as a contour plot, in an array of panels laid out on the same graphics display, using plot.solist. Invididual panels are plotted by contour.im.

See Also

plot.solist, contour.im

Examples

Run this code
# bei.extra is a named list of covariate images
 contour(bei.extra,
         main="Barro Colorado: covariates")

Run the code above in your browser using DataLab