Learn R Programming

spatstat.geom (version 3.7-2)

coords: Extract or Change Coordinates of a Spatial or Spatiotemporal Point Pattern

Description

Given any kind of spatial or space-time point pattern, this function extracts the (space and/or time and/or local) coordinates of the points and returns them as a data frame.

Usage

coords(x, ...)
  # S3 method for ppp
coords(x, ...)
  # S3 method for ppx
coords(x, ..., spatial = TRUE, temporal = TRUE, local=TRUE)
  coords(x, ...) <- value
  # S3 method for ppp
coords(x, ...) <- value
  # S3 method for ppx
coords(x, ..., spatial = TRUE, temporal = TRUE, local=TRUE) <- value
  # S3 method for quad
coords(x, ...)

Arguments

Value

coords returns a data.frame with one row for each point, containing the coordinates.

coords<- returns the altered point pattern.

Details

The function coords extracts the coordinates from a point pattern. The function coords<- replaces the coordinates of the point pattern with new values.

Both functions coords and coords<- are generic, with methods for the classes "ppp") and "ppx". An object of class "pp3" also inherits from "ppx" and is handled by the method for "ppx".

See Also

ppx, pp3, ppp, as.hyperframe.ppx, as.data.frame.ppx.

Examples

Run this code
   df <- data.frame(x=runif(4),y=runif(4),t=runif(4))
   X <- ppx(data=df, coord.type=c("s","s","t"))
   coords(X)
   coords(X, temporal=FALSE)
   coords(X) <- matrix(runif(12), ncol=3)

Run the code above in your browser using DataLab