This function computes the areas of the dilations of X
by each of the radii r[i]. Areas may also be computed
inside a specified window W.
The morphological dilation of a set \(X\) by a distance \(r > 0\)
is the subset
consisting of all points \(x\) such that the
distance from \(x\) to \(X\) is less than
or equal to \(r\).
When X is a point pattern, the dilation by a distance
\(r\) is the union of
discs of radius \(r\) centred at the points of X.
The argument r should be a vector of nonnegative numbers.
If exact=TRUE and if X is a point pattern,
then the areas are computed using analytic geometry, which is
slower but much more accurate. Otherwise the computation is performed
using distmap.
To compute the dilated object itself, use dilation.