Learn R Programming

spatstat.geom (version 3.2-9)

dirichletAreas: Compute Areas of Tiles in Dirichlet Tessellation

Description

Calculates the area of each tile in the Dirichlet-Voronoi tessellation of a point pattern.

Usage

dirichletAreas(X)

Value

Numeric vector with one entry for each point of X.

Arguments

X

Point pattern (object of class "ppp").

Author

Adrian Baddeley [email protected]

Rolf Turner [email protected]

and Ege Rubak [email protected]

Details

This is an efficient algorithm to calculate the areas of the tiles in the Dirichlet-Voronoi tessellation.

If the window of X is a binary pixel mask, the tile areas are computed by counting pixels. Otherwise the areas are computed exactly using analytic geometry.

If any points of X are duplicated, the duplicates will have tile area zero.

See Also

dirichlet, dirichletVertices

Examples

Run this code
 aa <- dirichletAreas(cells)

Run the code above in your browser using DataLab