distbdry: Distance To Boundary

View source: R/distbdry.R

distbdryR Documentation

Distance To Boundary

Description

Compute the distance from each point in a point pattern to the boundary of the spatial domain.

Usage

distbdry(X)

## S3 method for class 'ppp'
distbdry(X)

## S3 method for class 'pp3'
distbdry(X)

Arguments

X

A point pattern (class "ppp" or "pp3" or other classes).

Details

For each point X[i] this function computes the shortest distance to the boundary of the observation window or domain of the point pattern.

The function distbdry is generic, with methods for class "ppp", "pp3" and other classes.

For a two-dimensional spatial point pattern X of class "ppp", distbdry(X) is equivalent to bdist.points(X).

Value

A numeric vector with one entry for each point of X.

Author(s)

\spatstatAuthors

.

See Also

bdist.points

Examples

 distbdry(cells)[1:10]

spatstat.geom documentation built on July 24, 2026, 9:07 a.m.