Learn R Programming

spatstat.geom (version 3.7-3)

edges: Extract Boundary Edges of a Window.

Description

Extracts the boundary edges of a window and returns them as a line segment pattern.

Usage

edges(x, ..., window = NULL, check = FALSE)

Arguments

Value

A line segment pattern (object of class "psp").

Details

The boundary edges of the window x will be extracted as a line segment pattern.

See Also

perimeter for calculating the total length of the boundary.

Examples

Run this code
  edges(square(1))
  edges(letterR)

Run the code above in your browser using DataLab