Generic function for computing the intensity of a spatial dataset or spatial point process model.
intensity(X, ...)Usually a numeric value or vector.
A spatial dataset or a spatial point process model.
Further arguments depending on the class of X.
Adrian Baddeley Adrian.Baddeley@curtin.edu.au, Rolf Turner rolfturner@posteo.net and Ege Rubak rubak@math.aau.dk.
This is a generic function for computing the intensity of a spatial dataset
or spatial point process model. There are methods for point patterns
(objects of class "ppp") and fitted point process models
(objects of class "ppm").
The empirical intensity of a dataset is the average density
(the average amount of ‘stuff’ per unit area or volume).
The empirical intensity of a point pattern is computed by the
method intensity.ppp.
The theoretical intensity of a stochastic model is the expected density
(expected amount of ‘stuff’ per unit area or volume).
The theoretical intensity of a fitted point process model
of class "ppm" is computed by
the method intensity.ppm.
intensity.ppp,
intensity.ppm.
Type methods(intensity) to see a list of methods for other classes.