Learn R Programming

spatstat.geom (version 3.8-2)

mergeLevels: Merge Levels of a Factor

Description

Specified levels of the factor will be merged into a single level.

Usage

mergeLevels(.f, ...)

Arguments

Value

Another factor of the same length as .f

(or object of the same kind as .f).

Details

This utility function takes a factor .f and merges specified levels of the factor.

The grouping is specified by the arguments ... which must each be given in the form new=old, where new is the name for the new merged level, and old is a character vector containing the old levels that are to be merged.

The result is a new factor (or factor-valued object), in which the levels listed in old have been replaced by a single level new.

An argument of the form name=character(0) or name=NULL is interpreted to mean that all other levels of the old factor should be mapped to name.

See Also

Examples

Run this code
   likert <- c("Strongly Agree", "Agree", "Neutral",
               "Disagree", "Strongly Disagree")
   answers <- factor(sample(likert, 15, replace=TRUE), levels=likert)
   answers
   mergeLevels(answers, Positive=c("Strongly Agree", "Agree"),
                        Negative=c("Strongly Disagree", "Disagree"))

Run the code above in your browser using DataLab