mergeTiles: Merge Groups of Tiles in a Tessellation

View source: R/tess.R

mergeTilesR Documentation

Merge Groups of Tiles in a Tessellation

Description

Given a tessellation and a factor which classifies the tiles of the tessellation into groups, form the set union of each group of tiles, and construct the tessellation based on these merged tiles.

Usage

 mergeTiles(x, group, ...)

 ## S3 method for class 'tess'
mergeTiles(x, group, ...)

Arguments

x

A tessellation (object of class "tess").

group

A factor, with one entry for each tile of x, which classifies the tiles into groups.

...

Other arguments, currently ignored.

Value

A tessellation.

Author(s)

\adrian

.

See Also

tess

Examples

  D <- dirichlet(cells)
  g <- factor(sample(letters[1:4], npoints(cells), replace=TRUE))
  plot(D, values=g, main="tiles to be merged")
  plot(mergeTiles(D, g), do.col=TRUE, "merged")

spatstat.geom documentation built on March 21, 2026, 9:06 a.m.