This is a method for the generic function pairdist.
Given a point pattern X (an object of class "ppp"),
this function computes the Euclidean distances between all pairs of
points in X, and returns the matrix of distances.
Alternatively if periodic=TRUE and the window containing X is a
rectangle, then the distances will be computed in the `periodic'
sense (also known as `torus' distance): opposite edges of the
rectangle are regarded as equivalent.
This is meaningless if the window is not a rectangle.
If squared=TRUE then the squared Euclidean distances
\(d^2\) are returned, instead of the Euclidean distances \(d\).
The squared distances are faster to calculate, and are sufficient for
many purposes (such as finding the nearest neighbour of a point).
The argument method is not normally used. It is
retained only for checking the validity of the software.
If method = "interpreted" then the distances are
computed using interpreted R code only. If method="C"
(the default) then C code is used. The C code is somewhat faster.