Learn R Programming

spatstat.geom (version 3.7-3)

quantile.im: Sample Quantiles of Pixel Image

Description

Compute the sample quantiles of the pixel values of a given pixel image.

Usage

# S3 method for im
quantile(x, ...)

Arguments

Value

A vector of quantiles.

Details

This simple function applies the generic quantile operation to the pixel values of the image x.

This function is a convenient way to inspect an image and to obtain summary statistics. See the examples.

See Also

quantile, cut.im, im.object

Examples

Run this code
# artificial image data
Z <- setcov(square(1))

# find the quartiles
quantile(Z)

# find the deciles
quantile(Z, probs=(0:10)/10)

Run the code above in your browser using DataLab