Learn R Programming

spatstat.geom (version 3.7-2)

quantilefun.im: Quantile Function for Images

Description

Return the inverse function of the cumulative distribution function of pixel values in an image.

Usage

# S3 method for im
quantilefun(x, ..., type=1)

Arguments

Value

A function in the R language.

Details

Whereas the command quantile calculates the quantiles of a dataset corresponding to desired probabilities \(p\), the command quantilefun returns a function which can be used to compute any quantiles of the dataset.

If f <- quantilefun(x) then f is a function such that f(p) is the quantile associated with any given probability p. For example f(0.5) is the median of the original data, and f(0.99) is the 99th percentile of the original data.

If x is a pixel image (object of class "im") then the pixel values of x will be extracted and the quantile function of the pixel values is constructed.

See Also

quantilefun, ewcdf, quantile.ewcdf, ecdf, quantile

Examples

Run this code
  ## image data: terrain elevation
  Z <- bei.extra$elev
  if(require(spatstat.explore)) {
    FE <- spatialcdf(Z, normalise=TRUE)
  } else {
    FE <- ecdf(Z[])
  }
  QE <- quantilefun(FE)
  QE(0.5) # median elevation
  if(interactive()) plot(QE, xlim=c(0,1),
     xlab="probability", ylab="quantile of elevation")

Run the code above in your browser using DataLab