Learn R Programming

spatstat.geom (version 3.8-2)

restrict.colourmap: Restrict a Colour Map to a Subset of Values

Description

Given a colour map defined on a range of numerical values or a set of discrete inputs, the command restricts the range of values to a narrower range, or restricts the set of inputs to a subset, and returns the associated colour map.

Usage

restrict.colourmap(x, ..., range = NULL, breaks = NULL, inputs = NULL)

Arguments

Value

Colour map (object of class "colourmap").

Details

This command produces a new colour map y which is consistent with the original colour map x, except that y is defined on a narrower interval of numeric values, or a smaller set of discrete input values, than x.

See Also

colourmap

Examples

Run this code
  plot(a <- colourmap(topo.colors(128), range=c(-1,1)))
  plot(b <- restrict.colourmap(a, range=c(0,1)))

Run the code above in your browser using DataLab