Learn R Programming

spatstat.geom (version 3.7-3)

tilenames: Names of Tiles in a Tessellation

Description

Extract or Change the Names of the Tiles in a Tessellation.

Usage

tilenames(x)
tilenames(x) <- value

# S3 method for tess tilenames(x)

# S3 method for tess tilenames(x) <- value

Arguments

Value

tilenames returns a character vector.

Details

These functions extract or change the names of the tiles that make up the tessellation x.

If the tessellation is a regular grid, the tile names cannot be changed.

See Also

tess, tiles

Examples

Run this code
  D <- dirichlet(runifrect(10))
  tilenames(D)
  tilenames(D) <- paste("Cell", 1:10)
  tilenames(D)

Run the code above in your browser using DataLab