powered by
Given an infinite line and a spatial point location, determine which side of the line the point falls on.
whichhalfplane(L, x, y = NULL)
A logical matrix.
Object of class "infline" specifying one or more infinite straight lines in two dimensions.
"infline"
Arguments acceptable to xy.coords specifying the locations of the points.
xy.coords
Adrian Baddeley [email protected].
An infinite line \(L\) divides the two-dimensional plane into two half-planes. This function returns a matrix M of logical values in which M[i,j] = TRUE if the jth spatial point lies below or to the left of the ith line.
M
M[i,j] = TRUE
j
i
infline
L <- infline(p=runif(3), theta=runif(3, max=2*pi)) X <- runifrect(4) whichhalfplane(L, X)
Run the code above in your browser using DataLab