| FeretBox | R Documentation |
Given a spatial domain, calculate its Feret box, the narrowest rectangle enclosing the domain at a given angle (or at any angle).
FeretBox(W, theta = NULL)
W |
Window (object of class |
theta |
Either a single numeric value specifying an angle
such that the sides of the box should be parallel and perpendicular
to |
If theta is given, then the smallest rectangle containing W
with sides parallel and perpendicular to angle theta
will be computed and returned.
If theta=NULL (the default), then the orientation of the
rectangle is unconstrained. The rectangle with the narrowest possible
width (at any orientation) is determined by finding the minimum
Feret diameter.
A polygonal window (object of class "owin") representing a
rotated rectangle.
.
FeretDiamFun
W <- Window(chorley)
B <- FeretBox(W)
plot(B, main="", type="n")
plot(W, add=TRUE)
plot(B, add=TRUE, border="red")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.