The Feret diameter or caliper diameter of a domain \(W\), at a given angle
\(\theta\), is length of the projection of \(W\)
onto a line with orientation \(\theta\).
Equivalently, the Feret diameter at angle \(\theta\)
is the distance between the tangents to \(W\)
that are perpendicular to direction \(\theta\).
The Feret diameter at orientation \(\theta\)
can also be written
$$
d_W(\theta) = h_W(\theta) - h_W(\theta + \pi)
$$
where \(h_W(\theta)\) is the support function of W.
The command FeretDiamFun
creates a function in the R language, with one argument
theta, which can calculate the Feret diameter at any given
angle or angles theta.
The commands minFeretDiam and maxFeretDiam calculate
the minimum and maximum value, respectively, of Feret diameter at any orientation.