| SupportFun | R Documentation |
Create the support function of a two-dimensional domain.
SupportFun(W, origin = c(0, 0))
W |
Window (object of class |
origin |
The location of the origin for the support function.
Either a numeric vector of length 2 giving the location,
or a point pattern containing only one point,
or a list with two entries named |
The support function h_W(\theta) of a set W
is defined by
h_W(\theta) = \sup\{ x \cos\theta + y\sin\theta : (x,y) \in W \}
defined for all angles theta in (0, 2\pi).
For any direction theta (in radians),
h_W(\theta) is the signed distance from the origin
to a line which is tangent to W and perpendicular to theta.
The result of SupportFun(W) is a function in the R
language with one argument theta. This function can be applied
to any vector of values of \theta to compute the values
of the support function.
A function in the R language with one argument theta.
.
FeretDiamFun,
polarbody
W <- letterR
Frame(W) <- grow.rectangle(Frame(W), 0.2)
plot(W, main="")
f <- SupportFun(W)
p <- f(pi/6)
plot(infline(p=p, theta=pi/6), col="red", lwd=2)
## as a function
curve(f, to=2*pi)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.