This is a method for the generic contour function,
for objects of the class "im".
An object of class "im" represents a pixel image;
see im.object.
This function displays the values of the pixel image x
as a contour plot on the current plot device,
using equal scales on the \(x\) and \(y\) axes.
The appearance of the plot can be modified
using any of the arguments listed in the help for
contour.default.
Useful ones include:
- nlevels
Number of contour levels to plot.
- drawlabels
Whether to label the contour lines with text.
- col,lty,lwd
Colour, type, and width of contour lines.
See contour.default for a full list of these arguments.
The defaults for any of the abovementioned arguments
can be reset using spatstat.options("par.contour").
If log=TRUE, the contour lines will be evenly-spaced
on a logarithmic scale, provided the range of pixel values
is at least 1.5 orders of magnitude (a ratio of at least 32).
Otherwise the levels will be evenly-spaced on the original scale.
If col is a colour map (object of class "colourmap",
see colourmap) then the contours will be plotted in
different colours as determined by the colour map.
The contour at level z will be plotted
in the colour col(z) associated with this level in the colour map.