| distbdry | R Documentation |
Compute the distance from each point in a point pattern to the boundary of the spatial domain.
distbdry(X)
## S3 method for class 'ppp'
distbdry(X)
## S3 method for class 'pp3'
distbdry(X)
X |
A point pattern (class |
For each point X[i] this function computes the shortest
distance to the boundary of the observation window or domain of the
point pattern.
The function distbdry is generic, with methods for
class "ppp", "pp3" and other classes.
For a two-dimensional spatial point pattern X of class "ppp",
distbdry(X) is equivalent to bdist.points(X).
A numeric vector with one entry for each point of X.
.
bdist.points
distbdry(cells)[1:10]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.