Learn R Programming

spatstat.geom (version 3.8-2)

distbdry: Distance To Boundary

Description

Compute the distance from each point in a point pattern to the boundary of the spatial domain.

Usage

distbdry(X)

# S3 method for ppp distbdry(X)

# S3 method for pp3 distbdry(X)

Value

A numeric vector with one entry for each point of X.

Arguments

X

A point pattern (class "ppp" or "pp3" or other classes).

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au, Rolf Turner rolfturner@posteo.net and Ege Rubak rubak@math.aau.dk.

Details

For each point X[i] this function computes the shortest distance to the boundary of the observation window or domain of the point pattern.

The function distbdry is generic, with methods for class "ppp", "pp3" and other classes.

For a two-dimensional spatial point pattern X of class "ppp", distbdry(X) is equivalent to bdist.points(X).

See Also

bdist.points

Examples

Run this code
 distbdry(cells)[1:10]

Run the code above in your browser using DataLab