powered by
Extracts the boundary edges of a window and returns them as a line segment pattern.
edges(x, ..., window = NULL, check = FALSE)
A line segment pattern (object of class "psp").
"psp"
The boundary edges of the window x will be extracted as a line segment pattern.
x
perimeter for calculating the total length of the boundary.
perimeter
edges(square(1)) edges(letterR)
Run the code above in your browser using DataLab