| mergeTiles | R Documentation |
Given a tessellation and a factor which classifies the tiles of the tessellation into groups, form the set union of each group of tiles, and construct the tessellation based on these merged tiles.
mergeTiles(x, group, ...)
## S3 method for class 'tess'
mergeTiles(x, group, ...)
x |
A tessellation (object of class |
group |
A |
... |
Other arguments, currently ignored. |
A tessellation.
.
tess
D <- dirichlet(cells)
g <- factor(sample(letters[1:4], npoints(cells), replace=TRUE))
plot(D, values=g, main="tiles to be merged")
plot(mergeTiles(D, g), do.col=TRUE, "merged")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.