Learn R Programming

spatstat.geom (version 3.7-2)

mergeTiles: Merge Groups of Tiles in a Tessellation

Description

Given a tessellation and a factor which classifies the tiles of the tessellation into groups, form the set union of each group of tiles, and construct the tessellation based on these merged tiles.

Usage

mergeTiles(x, group, ...)

# S3 method for tess mergeTiles(x, group, ...)

Value

A tessellation.

Arguments

x

A tessellation (object of class "tess").

group

A factor, with one entry for each tile of x, which classifies the tiles into groups.

...

Other arguments, currently ignored.

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au.

See Also

tess

Examples

Run this code
  D <- dirichlet(cells)
  g <- factor(sample(letters[1:4], npoints(cells), replace=TRUE))
  plot(D, values=g, main="tiles to be merged")
  plot(mergeTiles(D, g), do.col=TRUE, "merged")

Run the code above in your browser using DataLab