powered by
Methods for geometrical transformations of layered objects (class "layered").
"layered"
# S3 method for layered c(...) # S3 method for layered shift(X, vec=c(0,0), ...) # S3 method for layered rotate(X, ..., centre=NULL) # S3 method for layered affine(X, ...) # S3 method for layered reflect(X) # S3 method for layered flipxy(X) # S3 method for layered rescale(X, s, unitname) # S3 method for layered scalardilate(X, ...)
# S3 method for layered shift(X, vec=c(0,0), ...)
# S3 method for layered rotate(X, ..., centre=NULL)
# S3 method for layered affine(X, ...)
# S3 method for layered reflect(X)
# S3 method for layered flipxy(X)
# S3 method for layered rescale(X, s, unitname)
# S3 method for layered scalardilate(X, ...)
Another object of class "layered".
These are methods for the generic functions c, shift, rotate, reflect, affine, rescale, scalardilate and flipxy for the class of layered objects.
c
shift
rotate
reflect
affine
rescale
scalardilate
flipxy
A layered object represents data that should be plotted in successive layers, for example, a background and a foreground. See layered.
layered
The method for c can be used to concatenate two or more layered objects ... into a single layered object, retaining the plot arguments.
...
The other methods apply geometrical operations to each of the layers of the layered object X.
X
B <- owin(c(5500, 9000), c(2500, 7400)) L <- layered(Window(demopat), unmark(demopat)[B]) plot(L) plot(rotate(L, pi/4))
Run the code above in your browser using DataLab