| polarbody | R Documentation |
Compute the polar body or the Voronoi flower of a two-dimensional domain.
polarbody(W, origin = c(0, 0), npoly = 512)
voronoiFlower(W, origin = c(0, 0), npoly = 512)
W |
Window (object of class |
origin |
The location of the origin for the support function.
Either a numeric vector of length 2 giving the location,
or a point pattern containing only one point,
or a list with two entries named |
npoly |
Number of edges in the approximating polygon. |
The polar body and Voronoi flower of a set W
are geometrical constructions based on the support function
h_W(\theta) of W.
The polar body of a two-dimensional domain W
is the set whose boundary has polar coordinates
(\theta, 1/h_W(\theta))
for all directions \theta.
The Voronoi flower is the set whose boundary has polar coordinates
(\theta, 2 h_W(\theta)).
A polygonal window (object of class "owin")
representing the polar body or the Voronoi flower.
.
SupportFun
plot(polarbody(letterR, "midpoint"))
plot(voronoiFlower(letterR, "midpoint"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.