Learn R Programming

spatstat.geom (version 3.7-2)

polarbody: Polar Body and Voronoi Flower

Description

Compute the polar body or the Voronoi flower of a two-dimensional domain.

Usage

polarbody(W, origin = c(0, 0), npoly = 512)

voronoiFlower(W, origin = c(0, 0), npoly = 512)

Value

A polygonal window (object of class "owin") representing the polar body or the Voronoi flower.

Arguments

W

Window (object of class "owin") representing the domain.

origin

The location of the origin for the support function. Either a numeric vector of length 2 giving the location, or a point pattern containing only one point, or a list with two entries named x and y, or one of the character strings "centroid", "midpoint", "left", "right", "top", "bottom", "topleft", "bottomleft", "topright" or "bottomright" (partially matched).

npoly

Number of edges in the approximating polygon.

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au.

Details

The polar body and Voronoi flower of a set \(W\) are geometrical constructions based on the support function \(h_W(\theta)\) of \(W\).

The polar body of a two-dimensional domain \(W\) is the set whose boundary has polar coordinates \((\theta, 1/h_W(\theta))\) for all directions \(\theta\).

The Voronoi flower is the set whose boundary has polar coordinates \((\theta, 2 h_W(\theta))\).

See Also

SupportFun

Examples

Run this code
  plot(polarbody(letterR, "midpoint"))

  plot(voronoiFlower(letterR, "midpoint"))

Run the code above in your browser using DataLab