The location of the origin for the support function.
Either a numeric vector of length 2 giving the location,
or a point pattern containing only one point,
or a list with two entries named x and y,
or one of the character strings
"centroid", "midpoint",
"left", "right", "top", "bottom",
"topleft", "bottomleft", "topright" or
"bottomright" (partially matched).