powered by
Compute the sample quantiles of the pixel values of a given pixel image.
# S3 method for im quantile(x, ...)
A vector of quantiles.
This simple function applies the generic quantile operation to the pixel values of the image x.
quantile
x
This function is a convenient way to inspect an image and to obtain summary statistics. See the examples.
quantile, cut.im, im.object
cut.im
im.object
# artificial image data Z <- setcov(square(1)) # find the quartiles quantile(Z) # find the deciles quantile(Z, probs=(0:10)/10)
Run the code above in your browser using DataLab