restrict.colourmap: Restrict a Colour Map to a Subset of Values
Description
Given a colour map defined on a range of numerical values or a set of
discrete inputs, the command restricts the range of values to a narrower range,
or restricts the set of inputs to a subset, and returns the associated
colour map.
This command produces a new colour map y which is consistent with the
original colour map x, except that y is defined on a
narrower interval of numeric values, or a smaller set of discrete
input values, than x.